<?xml version="1.0"?>
<app>

<category>
Children
</category>

<name>
Secondary
</name>

<description>
   <am>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</am>
   <ar>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ar>
   <bg>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</bg>
   <ca>Secundària: inclou calibre, celestia, dia, laby, lightspeed, melting, ri-li i stellarium</ca>
   <cs>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</cs>
   <da>Videregående skole. Inkluderer: calibre, celestia, dia, laby, lightspeed,  melting, ri-li og stellarium</da>
   <de>Oberschule: Beinhaltet: Kaliber, Celestia, Dia, Laby, Lightspeed, Schmelzen, Ri-li und Stellarium.</de>
   <el>Δευτεροβάθμιο σχολείο. Περιλαμβάνει: calibre, celestia, dia, laby, lightpeed, melting, ri-li και stellarium</el>
   <en>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</en>
   <es>Secondary incluye: alibre, celestia, dia, laby, lightspeed, melting, ri-li y stellarium</es>
   <et>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</et>
   <eu>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</eu>
   <fa>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</fa>
   <fi>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</fi>
   <fr>Secondaire. Inclus: calibre, celestia, dia, laby, lightspeed, melting, ri-li et stellarium</fr>
   <he_IL>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</he_IL>
   <hi>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</hi>
   <hr>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</hr>
   <hu>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</hu>
   <id>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</id>
   <is>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</is>
   <it>Superiori. Include: calibre, celestia, dia, laby, lightspeed, melting, ri-li e stellarium</it>
   <ja_JP>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ja_JP>
   <ja>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ja>
   <kk>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</kk>
   <ko>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ko>
   <lt>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</lt>
   <mk>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</mk>
   <nb>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</nb>
   <nl>Gevorderd. Inclusief: calibre, celestia, dia, laby, lightspeed, melting, ri-li  en stellarium</nl>
   <pl>Szkoła średnia: Zawiera: calibre, celestia, dia, laby, lightspeed, melting, ri-li i stellarium</pl>
   <pt_BR>Ensino fundamental (7º ao 9º ano). Inclui: calibre, celestia, dia, laby, lightspeed, melting, ri-li e stellarium</pt_BR>
   <pt>Ensino básico 3º ciclo. Inclui: calibre, celestia, dia, laby, lightspeed, melting, ri-li e stellarium</pt>
   <ro>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ro>
   <ru>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</ru>
   <sk>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</sk>
   <sl>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</sl>
   <sq>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</sq>
   <sr>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</sr>
   <sv>Secondary. Inkluderar: calibre, celestia, dia, laby, lightspeed, melting, ri-li och stellarium</sv>
   <tr>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</tr>
   <uk>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</uk>
   <zh_CN>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</zh_CN>
   <zh_TW>Secondary. Includes: calibre, celestia, dia, laby, lightspeed, melting, ri-li and stellarium</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
calibre
dia
laby
lightspeed
melting
ri-li
stellarium
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
calibre
dia
laby
lightspeed
melting
ri-li
stellarium
</uninstall_package_names>
</app>
